@@ -24,7 +24,7 @@ then
       echo "Building shared libraries"
 fi
 
-configure --prefix=`pwd` $CONF_STATIC LIBS="-lgsl -lgslcblas -lm"
+configure CXX=/home/lfinsto/gcc-4.8.2/bin/g++ LDFLAGS="-L/home/lfinsto/gcc-4.8.2/lib64/../lib64" --prefix=`pwd` $CONF_STATIC LIBS="-lgsl -lgslcblas -lm"
 
 if test $# -gt 1
 then
